
import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { BrowserRouter, Routes, Route, Navigate } from "react-router-dom";
import { lazy, Suspense } from "react";
import Header from "./components/layout/Header";
import { ScrollToTop } from "./components/layout/ScrollToTop";
import { FooterSection } from "./components/sections/FooterSection";
import { OptimizedCookieBanner } from "./components/layout/OptimizedCookieBanner";
import { CookieManager } from "./components/layout/CookieManager";
import { PerformanceProvider } from "./components/providers/PerformanceProvider";
import { AdminLayout } from "./components/admin/AdminLayout";
import { LazyAdminRoutes } from "./components/admin/LazyAdminRoutes";
import Index from "./pages/Index";
import { SimulatorRouter } from "./components/simulator/SimulatorRouter";
import { RedirectOldCityUrls } from "./components/layout/RedirectOldCityUrls";
import { CityPageRouter } from "./components/layout/CityPageRouter";

// Lazy loading des pages moins critiques
const Guide = lazy(() => import("./pages/Guide"));
const FAQ = lazy(() => import("./pages/FAQ"));
const Conseil = lazy(() => import("./pages/Conseil"));
const ConseilArticle = lazy(() => import("./pages/ConseilArticle"));
const Contact = lazy(() => import("./pages/Contact"));
const LegalNotice = lazy(() => import("./pages/LegalNotice"));
const PrivacyPolicy = lazy(() => import("./pages/PrivacyPolicy"));
const TermsOfService = lazy(() => import("./pages/TermsOfService"));
const CookiePolicy = lazy(() => import("./pages/CookiePolicy"));
const NotFound = lazy(() => import("./pages/NotFound"));
const AdminLogin = lazy(() => import("./pages/admin/AdminLogin"));

const queryClient = new QueryClient({
  defaultOptions: {
    queries: {
      staleTime: 5 * 60 * 1000, // 5 minutes
      gcTime: 10 * 60 * 1000, // 10 minutes
    },
  },
});

// Composant de chargement optimisé
const PageLoadingFallback = () => (
  <div className="min-h-screen flex items-center justify-center">
    <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-primary"></div>
  </div>
);

// Layout standard avec composants partagés
const StandardLayout = ({ children }: { children: React.ReactNode }) => (
  <div className="min-h-screen flex flex-col">
    <Header />
    <main className="pt-16 flex-1">
      {children}
    </main>
    <FooterSection />
    <OptimizedCookieBanner />
    <CookieManager />
  </div>
);

const App = () => {
  return (
    <QueryClientProvider client={queryClient}>
      <TooltipProvider>
        <Toaster />
        <Sonner />
        <BrowserRouter>
          <PerformanceProvider>
            <ScrollToTop />
            <Routes>
            {/* Routes d'administration avec lazy loading */}
            <Route path="/admin/login" element={
              <Suspense fallback={<PageLoadingFallback />}>
                <AdminLogin />
              </Suspense>
            } />
            <Route path="/admin/*" element={
              <AdminLayout>
                <LazyAdminRoutes />
              </AdminLayout>
            } />

            {/* Page d'accueil - priorité maximale, pas de lazy loading */}
            <Route path="/" element={
              <StandardLayout>
                <Index />
              </StandardLayout>
            } />
            
            {/* Simulateur - critique, pas de lazy loading */}
            <Route path="/simulateur" element={
              <StandardLayout>
                <SimulatorRouter />
              </StandardLayout>
            } />
            <Route path="/simulateur/:step" element={
              <StandardLayout>
                <SimulatorRouter />
              </StandardLayout>
            } />
            
            {/* Pages secondaires avec lazy loading */}
            <Route path="/conseil" element={
              <StandardLayout>
                <Suspense fallback={<PageLoadingFallback />}>
                  <Conseil />
                </Suspense>
              </StandardLayout>
            } />
            <Route path="/conseil/:slug" element={
              <StandardLayout>
                <Suspense fallback={<PageLoadingFallback />}>
                  <ConseilArticle />
                </Suspense>
              </StandardLayout>
            } />
            {/* Nouvelle structure URL pour les pages villes */}
            <Route path="*" element={
              <StandardLayout>
                <CityPageRouter />
              </StandardLayout>
            } />
            {/* Redirection des anciennes URLs ville vers apl */}
            <Route path="/ville/:slug" element={<RedirectOldCityUrls />} />
            <Route path="/guide" element={
              <StandardLayout>
                <Suspense fallback={<PageLoadingFallback />}>
                  <Guide />
                </Suspense>
              </StandardLayout>
            } />
            <Route path="/faq" element={
              <StandardLayout>
                <Suspense fallback={<PageLoadingFallback />}>
                  <FAQ />
                </Suspense>
              </StandardLayout>
            } />
            <Route path="/contact" element={
              <StandardLayout>
                <Suspense fallback={<PageLoadingFallback />}>
                  <Contact />
                </Suspense>
              </StandardLayout>
            } />
            <Route path="/legal-notice" element={
              <StandardLayout>
                <Suspense fallback={<PageLoadingFallback />}>
                  <LegalNotice />
                </Suspense>
              </StandardLayout>
            } />
            <Route path="/privacy-policy" element={
              <StandardLayout>
                <Suspense fallback={<PageLoadingFallback />}>
                  <PrivacyPolicy />
                </Suspense>
              </StandardLayout>
            } />
            <Route path="/cookie-policy" element={
              <StandardLayout>
                <Suspense fallback={<PageLoadingFallback />}>
                  <CookiePolicy />
                </Suspense>
              </StandardLayout>
            } />
            <Route path="/terms-of-service" element={
              <StandardLayout>
                <Suspense fallback={<PageLoadingFallback />}>
                  <TermsOfService />
                </Suspense>
              </StandardLayout>
            } />

            </Routes>
          </PerformanceProvider>
        </BrowserRouter>
      </TooltipProvider>
    </QueryClientProvider>
  );
};

export default App;
